Registracija | OiRA

Teme

# Registracija

## Zakaj se moram registrirati?

Pred začetkom svoje prve ocene tveganja ste najprej pozvani, da ustvarite račun OiRA, kar lahko storite enostavno in hitro.

Registracija vam omogoča, da se kadar koli prijavite in dostopate do svojih podatkov, nadaljujete prejšnjo oceno ali začnete novo.

Na podlagi registracije lahko sistem OiRA shrani vse vaše seje, vaši podatki pa so vam vedno na voljo.

Za več informacij o tem, kako ravnamo z vašimi osebnimi podatki, si preberite našo politiko zasebnosti.

## Kakšna je razlika med tem, da se registriram kot uporabnik ali izvedem poskusno sejo?

S poskusno sejo lahko zainteresirane strani preskusijo orodje, preden se odločijo za registracijo. Vaši podatki se med poskusno sejo ne shranijo, zato pozneje ne boste mogli pridobiti nobenih vnesenih informacij. V poskusni seji ne morete natisniti nobenih poročil, če pa registrirate svoj račun, lahko svojo oceno tveganja v celoti dokumentirate.

## Registracija novega računa

Ali ste to stran obiskali prvič? Za začetek registracije izvedite naslednje preproste korake:

1. Za ogled obrazca za registracijo kliknite ,Registriraj se‘.

Obrazec za registracijo.

1. Vnesite svoj e-poštni naslov in izberite geslo (vnesite ga dvakrat).

2. Za registracijo novega računa kliknite ,Naprej‘.

3. Za nadaljevanje preberite politiko zasebnosti in potrdite, da se strinjate z njo.

Zdaj ste prijavljeni v sistem OiRA.

## Prijava v obstoječi račun

Če ste se predhodno že registrirali, lahko do svojega računa dostopate na spodnji način:

1. Odprite obrazec za prijavo. Povezava do obrazca za prijavo se prikaže vsakič, ko želite dostopati do orodja OiRA, dokler se ne prijavite.

Obrazec za prijavo.

1. Vnesite svoj e-poštni naslov in geslo.

2. Za vpis kliknite gumb ,Prijava‘.

Ko ste prijavljeni, se prikaže spodnji zaslon. Na tej strani lahko začnete novo oceno tveganja ali se vrnete na ocene, ki ste jih že začeli.

Pregled.

Začnite novo oceno tveganja tako, da vnesete njen naslov (npr. Moje podjetje 2018-07-03), ali odprite eno od vaših predhodnih ocen tveganja. Vse vaše ocene tveganja se shranijo, da so dostopne za poznejšo uporabo, razen če se odločite, da jih boste zbrisali.

Scroll to top Load toolbar…
Back

## 1-registration.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More